==> zio-aws-codebuild_3-5.17.123.1-sources.jar: zio/aws/codebuild/model/RetryBuildBatchResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class RetryBuildBatchResponse(
    buildBatch: Option[zio.aws.codebuild.model.BuildBatch] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.RetryBuildBatchResponse = {
    import RetryBuildBatchResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.RetryBuildBatchResponse
      .builder()
      .optionallyWith(buildBatch.map(value => value.buildAwsValue()))(
        _.buildBatch
      )
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.RetryBuildBatchResponse.ReadOnly =
    zio.aws.codebuild.model.RetryBuildBatchResponse.wrap(buildAwsValue())
}
object RetryBuildBatchResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.RetryBuildBatchResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.RetryBuildBatchResponse =
      zio.aws.codebuild.model
        .RetryBuildBatchResponse(buildBatch.map(value => value.asEditable))
    def buildBatch: Option[zio.aws.codebuild.model.BuildBatch.ReadOnly]
    def getBuildBatch
        : ZIO[Any, AwsError, zio.aws.codebuild.model.BuildBatch.ReadOnly] =
      AwsError.unwrapOptionField("buildBatch", buildBatch)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.RetryBuildBatchResponse
  ) extends zio.aws.codebuild.model.RetryBuildBatchResponse.ReadOnly {
    override val buildBatch
        : Option[zio.aws.codebuild.model.BuildBatch.ReadOnly] = scala
      .Option(impl.buildBatch())
      .map(value => zio.aws.codebuild.model.BuildBatch.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.RetryBuildBatchResponse
  ): zio.aws.codebuild.model.RetryBuildBatchResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-codebuild_3-5.17.267.1-sources.jar: zio/aws/codebuild/model/RetryBuildBatchResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class RetryBuildBatchResponse(
    buildBatch: Optional[zio.aws.codebuild.model.BuildBatch] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.RetryBuildBatchResponse = {
    import RetryBuildBatchResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.RetryBuildBatchResponse
      .builder()
      .optionallyWith(buildBatch.map(value => value.buildAwsValue()))(
        _.buildBatch
      )
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.RetryBuildBatchResponse.ReadOnly =
    zio.aws.codebuild.model.RetryBuildBatchResponse.wrap(buildAwsValue())
}
object RetryBuildBatchResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.RetryBuildBatchResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.RetryBuildBatchResponse =
      zio.aws.codebuild.model
        .RetryBuildBatchResponse(buildBatch.map(value => value.asEditable))
    def buildBatch: Optional[zio.aws.codebuild.model.BuildBatch.ReadOnly]
    def getBuildBatch
        : ZIO[Any, AwsError, zio.aws.codebuild.model.BuildBatch.ReadOnly] =
      AwsError.unwrapOptionField("buildBatch", buildBatch)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.RetryBuildBatchResponse
  ) extends zio.aws.codebuild.model.RetryBuildBatchResponse.ReadOnly {
    override val buildBatch
        : Optional[zio.aws.codebuild.model.BuildBatch.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.buildBatch())
        .map(value => zio.aws.codebuild.model.BuildBatch.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.RetryBuildBatchResponse
  ): zio.aws.codebuild.model.RetryBuildBatchResponse.ReadOnly = new Wrapper(
    impl
  )
}
